import requests
import base64
import getpass

# This function do the same thing as you can see in the file : authentification.py
# We juste create this function to have more efficiency in the others examples.py
# We also added login information in a .env file to not write login information in each files in /examples
def authenticate(username, password, baseurl):
    """
    Authentification thanks to API.

    Args:
        username (str): Username/email.
        password (str): Password.
        baseurl (str): URL of the API.

    Returns:
        dict: Authentification headers.
    """
    try:
        # Encode the login information in base64
        credentials = f"{username}:{password}"
        encoded_credentials = base64.b64encode(credentials.encode('utf-8')).decode('utf-8')
        
        # Create the authetification header
        authentication_header = {"Authorization": f"Basic {encoded_credentials}"}
        
        # Send the authentication demand
        resp = requests.post(f"{baseurl}/users/token", headers=authentication_header)
        resp.raise_for_status() # Raise http errors
        
        # Retrieve the authentification headers
        token = resp.json()
        headers = {"content-type":"application/json", "Authorization":f"Bearer {token['data']['AccessToken']}"}

        return headers
    except requests.exceptions.RequestException as e:
        print("Error during the request:", e)
        return None

if __name__ == "__main__":
    username = input("Username/email: ") # Allows you to enter your username/email in the terminal
    password = getpass.getpass("Password: ") # Allows you to enter your password in the terminal
    baseurl = "https://wmc.wanesy.com/api/v1" # baseURL for WMP4. Need to adapt if you have a different WMP4

    headers = authenticate(username, password, baseurl)

    if headers:
        print("Authentification successful !")
        print("Headers:", headers)
    else:
        print("Fail during authentication")
