import requests
import getpass

from examples.authentification.authentification_function import authenticate

baseurl = "https://wmc.wanesy.com/api/v1" # base url for WMP4

# Ask for the login informations
username = input("Username/email: ") # Allows you to enter your username/email in the terminal
password = getpass.getpass("Password: ") # Allows you to enter your password in the terminal

# Authentication like in authentication.py ==> Headers of Authentication is needed for every requests
headers = authenticate(username=username, password=password,baseurl=baseurl)
# Look line number 4 (l.4) to understand how transfer the authenticate function from authentication_function.py

########################
## Get list customers ##
########################
# No role needed
print("Get list customers")
url_get_list_customer = f"{baseurl}/customers"
# If you want to choose the number limit of customer per request; you can choose between 5,10,25,50 & 100, for 50 : add ?limit=50 ==> Example : f"{baseurl}/customers?limit=50"
# By default its 10
resp = requests.get(url_get_list_customer, headers=headers)
resp.raise_for_status()
customer_list = resp.json()
# print(customer_list) # Decomment to see the complete response
# If you want just want to check the datas of customers. Search in the 'data' fields.
for customer in customer_list['data']:
    # Here we will display id and name for each customer:
    print(f"id : {customer['id']} | name : {customer['name']}")

print("Pagination")
print("Get the following customers")
# If you want to get the following customers ==> Manage Pagination
# Check in your response (customer_list) the value in the field "totalCount" in the "metadata" field.
total_count = customer_list["metadata"]["totalCount"]
# To get and count the customers you already have. Create a set() and add it in.
customer_ids = set()
for customer in customer_list['data']:
    customer_ids.add(int(customer['id']))
# Display the ids of the customers (customer_ids) & the number of customer (len(customer_ids)) you have in your first request.
print("Display customer ids & number of customers of your first request")
nb_customers=len(customer_ids)
print(customer_ids,'==> Number of customers ==>',nb_customers)
# If this value is biggest than the number of customer you have; then, add the number of customer you have in the "offset" field in your next url.
print("Display the following customers")
if total_count > nb_customers:
    next_url=f'{url_get_list_customer}?offset={nb_customers}' # It's like : f"{baseurl}/customers?offset={nb_customers}"
    # Same methods than the first request
    resp = requests.get(next_url, headers=headers)
    resp.raise_for_status()
    next_customer_list = resp.json()
    for next_customer in next_customer_list['data']:
        print(f"id : {next_customer['id']} | name : {next_customer['name']}")
else:
    print("No others customers")
