import requests
import getpass

from examples.authentification.authentification_function import authenticate

baseurl = "https://wmc.wanesy.com/api/v1" # base url for WMP4

# Ask for the login informations
username = input("Username/email: ") # Allows you to enter your username/email in the terminal
password = getpass.getpass("Password: ") # Allows you to enter your password in the terminal

# Authentication like in authentication.py ==> Headers of Authentication is needed for every requests
headers = authenticate(username=username, password=password,baseurl=baseurl)
# Look line number 4 (l.4) to understand how transfer the authenticate function from authentication_function.py

# Paremeters you need to complete :
CUSTOMER_ID= input("Customer id: ") # Put a customer id.


############################
## Get full list gateways ##
############################
# No role needed
print("Get full list gateways")

# Initial URL for the first request
url_get_list_gateway = f"{baseurl}/customers/{CUSTOMER_ID}/gateways" # Here we limit to 10 gateways (default value)
# If you add a limit with : '?limit=5' or others values. Think about change '?offset' by '&offset' for the url in the pagination loop

# Initialize variables for pagination
page=0
offset = 0
all_gateways = []

# Pagination loop
while True:
    # Construct URL for current request with offset
    url = f"{url_get_list_gateway}?offset={offset}"

    # Send request
    resp = requests.get(url, headers=headers)
    resp.raise_for_status()
    gateway_list = resp.json()
    real_gateway_list = gateway_list['data']

    # Add gateways to list
    all_gateways.extend(real_gateway_list)

    # Display the page value and the gateway requested
    print()
    print(f"Page number {page} of your Pagination") if offset > 0 else print("Initial Page")
    # Print requested gateways
    for gateway in real_gateway_list:
        print(f"Gateway Eui : {gateway['gwEui']} | Name : {gateway['name']}")

    # Increase offset by the number of gateways received
    offset += len(real_gateway_list)

    # Increment the value of page
    page+=1

    # If the total count of gateways has been reached, break the loop
    if offset >= gateway_list["metadata"]["totalCount"]:
        break

print()
# Final Results
print("Final Results")
# Number of gateways
print(f"Number of gateways : {len(all_gateways)}")

##########################################################################################################################################
## If you want to display all the gateways for your customer at the same time without the number of page, decomment the following lines ##
##########################################################################################################################################

# print(f"List of all gateways for the customer : {CUSTOMER_ID}")
# for gateway in all_gateways:
#     print(f"Gateway Eui : {gateway['gwEui']} | Name : {gateway['name']}")
