import requests
import getpass

from examples.authentification.authentification_function import authenticate

baseurl = "https://wmc.wanesy.com/api/v1" # base url for WMP4

# Ask for the login informations
username = input("Username/email: ") # Allows you to enter your username/email in the terminal
password = getpass.getpass("Password: ") # Allows you to enter your password in the terminal

# Authentication like in authentication.py ==> Headers of Authentication is needed for every requests
headers = authenticate(username=username, password=password,baseurl=baseurl)
# Look line number 4 (l.4) to understand how transfer the authenticate function from authentication_function.py

# Paremeters you need to complete :
CUSTOMER_ID= input("Customer id: ") # Put a customer id.

########################
## Get list gateways ##
########################
# No role needed
print("Get list gateways")
# Here you need a customer id. Let's take : CUSTOMER_ID
url_get_list_gateway = f"{baseurl}/customers/{CUSTOMER_ID}/gateways?limit=5" # Here we limit to 5 gateways
# If you want to choose the number limit of gateway per request; you can choose between 5,10,25,50 & 100, for 50 : add ?limit=50 ==> Example : f"{baseurl}/customers/{CUSTOMER_ID}/gateways?limit=50"
# By default its 10
resp = requests.get(url_get_list_gateway, headers=headers)
resp.raise_for_status()
gateway_list = resp.json()
# print(gateway_list) # Decomment to see the complete response
# If you want just want to check the datas of gateways. Search in the 'data' fields.
for gateway in gateway_list['data']:
    # Here we will display gateway Eui and name for each gateway:
    print(f"Gateway Eui : {gateway['gwEui']} | name : {gateway['name']}")

print("Pagination")
print("Get the following gateways")
# If you want to get the following gateways ==> Manage Pagination
# Check in your response (gateway_list) the value in the field "totalCount" in the "metadata" field.
total_count = gateway_list["metadata"]["totalCount"]
# To get and count the gateways you have. Create a set() and add it in.
gateway_ids = set()
for gateway in gateway_list['data']:
    gateway_ids.add(gateway['gwEui'])
# Display the ids of the gateways (gateway_ids) & the number of gateway (len(gateway_ids)) you have in your first request.
print("Display gateway ids & number of gateways of your first request")
nb_gateways=len(gateway_ids)
print(gateway_ids,'==> Number of gateways ==>',nb_gateways)
# If this value is biggest than the number of gateway you have; then, add the number of gateway you have in the "offset" field in your next url.
print("Display the following gateways")
if total_count > nb_gateways:
    next_url=f'{url_get_list_gateway}&offset={nb_gateways}' # It's like : f"{baseurl}/customers/{CUSTOMER_ID}/gateways?limit=5&offset={nb_gateways}"
    # Same methods than the first request
    resp = requests.get(next_url, headers=headers)
    resp.raise_for_status()
    next_gateway_list = resp.json()
    for next_gateway in next_gateway_list['data']:
        print(f"Gateway Eui : {next_gateway['gwEui']} | name : {next_gateway['name']}")
else:
    print("No others gateway")

print()
# To understand Full Pagination, take a look at : get_full_list_gateway.py
print("If you want to understand how to manage the full pagination")
print("Take a look at : get_full_list_gateway.py")